MethodChannelMidiCommand class

A MidiCommandPlatform implementation backed by generated Pigeon APIs.

Inheritance

Constructors

MethodChannelMidiCommand({MidiHostApi? hostApi, MidiFlutterApiSetUp? flutterApiSetUp})

Properties

devices Future<List<MidiDevice>?>
Returns a list of found MIDI devices.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isNetworkSessionEnabled Future<bool?>
Returns the current state of the network session
no setteroverride
onMidiDataReceived Stream<MidiPacket>?
Stream firing events whenever a midi package is received.
no setteroverride
onMidiSetupChanged Stream<MidiSetupChange>?
Stream firing events whenever a change in the MIDI setup occurs.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addVirtualDevice({String? name}) → void
Creates a virtual MIDI source
override
connectToDevice(MidiDevice device, {List<MidiPort>? ports}) Future<void>
Connects to the device.
override
disconnectDevice(MidiDevice device) → void
Disconnects from the device.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDataReceived(MidiPacket packet) → void
onDeviceConnectionStateChanged(String deviceId, bool connected) → void
onSetupChanged(MidiSetupChange setupChange) → void
removeVirtualDevice({String? name}) → void
Removes a previously addd virtual MIDI source.
override
sendData(Uint8List data, {int? timestamp, String? deviceId}) → void
Sends data to the currently connected device.
override
setNetworkSessionEnabled(bool enabled) → void
Sets the enabled state of the network session
override
teardown() → void
Disconnects from all devices.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited