MidiConnectionTimeoutException class
- Inheritance
-
- Object
- MidiConnectionException
- MidiConnectionTimeoutException
Constructors
- MidiConnectionTimeoutException({required String deviceId, required MidiConnectionStage stage, required Duration? timeout, Object? cause})
Properties
- cause → Object?
-
finalinherited
- deviceId → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stage → MidiConnectionStage
-
finalinherited
- timeout → Duration?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited