MidiConnectionException class

Implemented types
Implementers

Constructors

MidiConnectionException({required String deviceId, required MidiConnectionStage stage, required String message, Object? cause})

Properties

cause → Object?
final
deviceId → String
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stage → MidiConnectionStage
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited