MidiDevice class

Constructors

MidiDevice(String id, String name, MidiDeviceType type, bool connected)

Properties

connected ↔ bool
getter/setter pair
connectionState → MidiConnectionState
no setter
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
inputPorts ↔ List<MidiPort>
Ports that receive MIDI data into this device.
getter/setter pair
name ↔ String
getter/setter pair
onConnectionStateChanged → Stream<MidiConnectionState>
no setter
outputPorts ↔ List<MidiPort>
Ports that send MIDI data out of this device.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ MidiDeviceType
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setConnectionState(MidiConnectionState value) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited